import numpy as np
from astropy.coordinates import CartesianRepresentation, SphericalRepresentation


def rotation_matrix(phi, theta) -> np.ndarray:
    """
    Rotate a vector represented in spherical coordinates.

    Args:
        phi (float): Azimuthal angle in radians.
        theta (float): Polar angle in radians.
    """
    # Construct the rotation matrix directly in spherical coordinates
    rot_phi = np.array([[np.cos(phi), -np.sin(phi), 0], [np.sin(phi), np.cos(phi), 0], [0, 0,
                                                                                        1]])  # Rotation around z-axis

    rot_theta = np.array([[np.sin(theta), 0, np.cos(theta)], [0, 1, 0], [-np.cos(theta), 0,
                                                                         np.sin(theta)]])  # Rotation around y-axis

    # Combine the rotation matrices
    rotation_matrix = np.dot(rot_phi, rot_theta)

    return rotation_matrix


def coord_to_polar(coord):
    return coord.lon.to_value('rad'), coord.radius.to_value('AU')


def xyz_to_polar(x, y, z):
    cart = CartesianRepresentation(x, y, z)
    sph = cart.represent_as(SphericalRepresentation)
    return sph.lon.value, sph.distance.value
